summaryrefslogtreecommitdiff
path: root/mali_kbase/mali_kbase_mem.h
diff options
context:
space:
mode:
Diffstat (limited to 'mali_kbase/mali_kbase_mem.h')
-rw-r--r--mali_kbase/mali_kbase_mem.h13
1 files changed, 8 insertions, 5 deletions
diff --git a/mali_kbase/mali_kbase_mem.h b/mali_kbase/mali_kbase_mem.h
index 371d788..c2b10e0 100644
--- a/mali_kbase/mali_kbase_mem.h
+++ b/mali_kbase/mali_kbase_mem.h
@@ -1,7 +1,7 @@
/* SPDX-License-Identifier: GPL-2.0 WITH Linux-syscall-note */
/*
*
- * (C) COPYRIGHT 2010-2023 ARM Limited. All rights reserved.
+ * (C) COPYRIGHT 2010-2024 ARM Limited. All rights reserved.
*
* This program is free software and is provided to you under the terms of the
* GNU General Public License version 2 as published by the Free Software
@@ -1674,7 +1674,7 @@ int kbase_alloc_phy_pages_helper(struct kbase_mem_phy_alloc *alloc, size_t nr_pa
*
* @prealloc_sa: Information about the partial allocation if the amount of memory requested
* is not a multiple of 2MB. One instance of struct kbase_sub_alloc must be
* allocated by the caller if kbdev->pagesize_2mb is enabled.
*
* Allocates @nr_pages_requested and updates the alloc object. This function does not allocate new
* pages from the kernel, and therefore will never trigger the OoM killer. Therefore, it can be
@@ -1702,9 +1702,9 @@ int kbase_alloc_phy_pages_helper(struct kbase_mem_phy_alloc *alloc, size_t nr_pa
* This ensures that the pool can be grown to the required size and that the allocation can
* complete without another thread using the newly grown pages.
*
* If kbdev->pagesize_2mb is enabled and the allocation is >= 2MB, then @pool must be one of the
* pools from alloc->imported.native.kctx->mem_pools.large[]. Otherwise it must be one of the
* mempools from alloc->imported.native.kctx->mem_pools.small[].
*
* @prealloc_sa is used to manage the non-2MB sub-allocation. It has to be pre-allocated because we
* must not sleep (due to the usage of kmalloc()) whilst holding pool->pool_lock. @prealloc_sa
@@ -2618,4 +2618,7 @@ static inline base_mem_alloc_flags kbase_mem_group_id_set(int id)
{
return BASE_MEM_GROUP_ID_SET(id);
}
+
+bool kbase_is_large_pages_enabled(void);
+
#endif /* _KBASE_MEM_H_ */
@@ -1674,7 +1674,7 @@ int kbase_alloc_phy_pages_helper(struct kbase_mem_phy_alloc *alloc, size_t nr_pa
* @prealloc_sa: Information about the partial allocation if the amount of memory requested
* is not a multiple of 2MB. One instance of struct kbase_sub_alloc must be
- * allocated by the caller if kbdev->pagesize_2mb is enabled.
+ * allocated by the caller if large pages are enabled.
*
* Allocates @nr_pages_requested and updates the alloc object. This function does not allocate new
@@ -1702,9 +1702,9 @@ int kbase_alloc_phy_pages_helper(struct kbase_mem_phy_alloc *alloc, size_t nr_pa
* complete without another thread using the newly grown pages.
*
- * If kbdev->pagesize_2mb is enabled and the allocation is >= 2MB, then @pool must be one of the
- * pools from alloc->imported.native.kctx->mem_pools.large[]. Otherwise it must be one of the
- * mempools from alloc->imported.native.kctx->mem_pools.small[].
+ * If large (2MiB) pages are enabled and the allocation is >= 2MiB, then @pool
+ * must be one of the pools from alloc->imported.native.kctx->mem_pools.large[]. Otherwise it
+ * must be one of the mempools from alloc->imported.native.kctx->mem_pools.small[].
*
* @prealloc_sa is used to manage the non-2MB sub-allocation. It has to be pre-allocated because we